@@ -19,7 +19,7 @@ import Control.DeepSeq
 import Control.Exception
 import           Data.ByteString as BS
 import qualified Data.ByteString.Lazy as BL
-import Data.List as L
+import qualified Data.List as L
 import Data.Maybe
 import Data.Typeable
 import System.Environment
@@ -90,7 +90,7 @@ data Torrent = Torrent {
   } deriving (Show, Eq, Typeable)
 
 instance NFData Torrent where
-  rnf Torrent {..} = ()
+  rnf Torrent {} = ()
 
 instance C.BEncode Torrent where
   toBEncode Torrent {..} = toDict $
