@@ -668,19 +668,13 @@ endDict = Nil
 --  \"length\" '<' \"md5sum\" '<' \"path\" '<' \"tags\"
 --
 newtype Get a = Get { runGet :: StateT BDict Result a }
-  deriving (Functor, Applicative, Alternative)
+  deriving (Functor, Applicative)
 
 -- | 'fail' is catchable from pure code.
 instance Monad Get where
-  return a = Get (return a)
-  {-# INLINE return #-}
-
   Get m >>= f = Get (m >>= runGet . f)
   {-# INLINE (>>=) #-}
 
-  Get m >> Get n = Get (m >> n)
-  {-# INLINE (>>) #-}
-
 #if __GLASGOW_HASKELL__ < 808
   fail msg = Get (lift (Left msg))
   {-# INLINE fail #-}
@@ -690,6 +684,11 @@ instance MonadFail Get where
   {-# INLINE fail #-}
 #endif
 
+-- | NOTE: @'Control.Applicative.empty' = 'fail' ""@.
+instance Alternative Get where
+  empty = fail ""
+  Get (StateT m) <|> Get (StateT n) = Get $ StateT $ \s -> m s <> n s
+
 -- | Run action, but return without consuming and key\/value pair.
 -- Fails if the action fails.
 lookAhead :: Get a -> Get a
